@@ -1,4 +1,4 @@
-from drf_spectacular.authentication import OpenApiAuthenticationExtension
+from drf_spectacular.extensions import OpenApiAuthenticationExtension
 
 
 class SimpleJWTScheme(OpenApiAuthenticationExtension):
@@ -21,6 +21,20 @@ class SimpleJWTScheme(OpenApiAuthenticationExtension):
         }
 
 
+class JWTScheme(OpenApiAuthenticationExtension):
+    target_class = 'rest_framework_jwt.authentication.JSONWebTokenAuthentication'
+    name = 'jwtAuth'
+
+    def get_security_definition(self, auto_schema):
+        from rest_framework_jwt.settings import api_settings
+
+        return {
+            'type': 'http',
+            'scheme': 'bearer',
+            'bearerFormat': api_settings.JWT_AUTH_HEADER_PREFIX,
+        }
+
+
 class DjangoOAuthToolkitScheme(OpenApiAuthenticationExtension):
     target_class = 'oauth2_provider.contrib.rest_framework.OAuth2Authentication'
     name = 'oauth2'
