@@ -4,10 +4,8 @@ from urllib.parse import urljoin
 from django.urls import URLResolver, URLPattern
 from rest_framework import viewsets, views
 from rest_framework.compat import get_original_route
-from rest_framework.schemas.generators import (
-    BaseSchemaGenerator,
-    EndpointEnumerator as BaseEndpointEnumerator,
-)
+from rest_framework.schemas.generators import BaseSchemaGenerator  # type: ignore
+from rest_framework.schemas.generators import EndpointEnumerator as BaseEndpointEnumerator
 
 from drf_spectacular.extensions import OpenApiViewExtension
 from drf_spectacular.plumbing import (
@@ -151,7 +149,10 @@ class SchemaGenerator(BaseSchemaGenerator):
     def get_schema(self, request=None, public=False):
         """ Generate a OpenAPI schema. """
         reset_generator_stats()
-        return build_root_object(
+        result = build_root_object(
             paths=self.parse(request, public),
             components=self.registry.build(spectacular_settings.APPEND_COMPONENTS),
         )
+        for hook in spectacular_settings.POSTPROCESSING_HOOKS:
+            result = hook(result=result, generator=self, request=request, public=public)
+        return result
