@@ -2,11 +2,10 @@ from textwrap import dedent
 
 from django.core.management.base import BaseCommand
 from django.utils.module_loading import import_string
-from rest_framework import renderers
 
 from drf_spectacular.settings import spectacular_settings
 from drf_spectacular.plumbing import GENERATOR_STATS
-from drf_spectacular.renderers import NoAliasOpenAPIRenderer
+from drf_spectacular.renderers import OpenApiYamlRenderer, OpenApiJsonRenderer
 from drf_spectacular.validation import validate_schema
 
 
@@ -30,6 +29,7 @@ class Command(BaseCommand):
         parser.add_argument('--file', dest="file", default=None, type=str)
         parser.add_argument('--fail-on-warn', dest="fail_on_warn", default=False, action='store_true')
         parser.add_argument('--validate', dest="validate", default=False, action='store_true')
+        parser.add_argument('--api-version', dest="api_version", default=None, type=str)
 
     def handle(self, *args, **options):
         if options['generator_class']:
@@ -37,13 +37,16 @@ class Command(BaseCommand):
         else:
             generator_class = spectacular_settings.DEFAULT_GENERATOR_CLASS
 
-        generator = generator_class(urlconf=options['urlconf'])
+        generator = generator_class(
+            urlconf=options['urlconf'],
+            api_version=options['api_version'],
+        )
         schema = generator.get_schema(request=None, public=True)
 
-        if options['fail_on_warn'] and GENERATOR_STATS.warn_counter:
-            raise RuntimeError(
-                f'Failing as requested due to {GENERATOR_STATS.warn_counter} warnings'
-            )
+        GENERATOR_STATS.emit_summary()
+
+        if options['fail_on_warn'] and GENERATOR_STATS:
+            raise RuntimeError('Failing as requested due to warnings')
         if options['validate']:
             validate_schema(schema)
 
@@ -58,7 +61,7 @@ class Command(BaseCommand):
 
     def get_renderer(self, format):
         renderer_cls = {
-            'openapi': NoAliasOpenAPIRenderer,
-            'openapi-json': renderers.JSONOpenAPIRenderer,
+            'openapi': OpenApiYamlRenderer,
+            'openapi-json': OpenApiJsonRenderer,
         }[format]
         return renderer_cls()
