@@ -11,6 +11,7 @@ from django.db import models
 from rest_framework import permissions, renderers, serializers
 from rest_framework.fields import _UnvalidatedField, empty
 from rest_framework.generics import GenericAPIView
+from rest_framework.mixins import ListModelMixin
 from rest_framework.schemas.inspectors import ViewInspector
 from rest_framework.schemas.utils import get_pk_description  # type: ignore
 from rest_framework.settings import api_settings
@@ -27,7 +28,8 @@ from drf_spectacular.plumbing import (
     build_basic_type, warn, anyisinstance, force_instance, is_serializer,
     follow_field_source, is_field, is_basic_type, build_array_type,
     ComponentRegistry, ResolvedComponent, build_parameter_type, error,
-    resolve_regex_path_parameter, safe_ref, has_override, get_override, append_meta,
+    resolve_regex_path_parameter, safe_ref, has_override, get_override,
+    append_meta, build_object_type,
 )
 from drf_spectacular.types import OpenApiTypes
 from drf_spectacular.utils import OpenApiParameter
@@ -101,6 +103,8 @@ class AutoSchema(ViewInspector):
         # list responses are "usually" only returned by GET
         if self.method.lower() != 'get':
             return False
+        if isinstance(self.view, ListModelMixin):
+            return True
         # primary key/lookup variable in path is a strong indicator for retrieve
         if isinstance(self.view, GenericAPIView):
             lookup_url_kwarg = self.view.lookup_url_kwarg or self.view.lookup_field
@@ -422,6 +426,8 @@ class AutoSchema(ViewInspector):
         # Related fields.
         if isinstance(field, serializers.ManyRelatedField):
             schema = self._map_serializer_field(field.child_relation, direction)
+            # remove hand-over initkwargs applying only to outer scope
+            schema.pop('description', None)
             return append_meta(build_array_type(schema), meta)
 
         if isinstance(field, serializers.PrimaryKeyRelatedField):
@@ -434,7 +440,7 @@ class AutoSchema(ViewInspector):
                 schema = self._map_model_field(field.parent.Meta.model._meta.pk, direction)
             # primary keys are usually non-editable (readOnly=True) and map_model_field correctly
             # signals that attribute. however this does not apply in the context of relations.
-            del schema['readOnly']
+            schema.pop('readOnly', None)
             return append_meta(schema, meta)
 
         if isinstance(field, serializers.StringRelatedField):
@@ -479,6 +485,9 @@ class AutoSchema(ViewInspector):
         if isinstance(field, serializers.DateTimeField):
             return append_meta(build_basic_type(OpenApiTypes.DATETIME), meta)
 
+        if isinstance(field, serializers.TimeField):
+            return append_meta(build_basic_type(OpenApiTypes.TIME), meta)
+
         if isinstance(field, serializers.EmailField):
             return append_meta(build_basic_type(OpenApiTypes.EMAIL), meta)
 
@@ -535,7 +544,7 @@ class AutoSchema(ViewInspector):
             method = getattr(field.parent, field.method_name)
             return append_meta(self._map_response_type_hint(method), meta)
 
-        if isinstance(field, serializers.BooleanField):
+        if anyisinstance(field, [serializers.BooleanField, serializers.NullBooleanField]):
             return append_meta(build_basic_type(OpenApiTypes.BOOL), meta)
 
         if anyisinstance(field, [serializers.JSONField, serializers.DictField, serializers.HStoreField]):
@@ -642,18 +651,15 @@ class AutoSchema(ViewInspector):
 
             properties[field.field_name] = safe_ref(schema)
 
-        result = {
-            'type': 'object',
-            'properties': properties
-        }
-
         if spectacular_settings.COMPONENT_SPLIT_PATCH:
             if self.method == 'PATCH' and direction == 'request':
                 required = []
-        if required:
-            result['required'] = sorted(required)
 
-        return result
+        return build_object_type(
+            properties=properties,
+            required=required,
+            description=inspect.getdoc(serializer),
+        )
 
     def _map_field_validators(self, field, schema):
         for v in field.validators:
@@ -791,11 +797,10 @@ class AutoSchema(ViewInspector):
                 f'could not resolve request body for {self.method} {self.path}. defaulting to generic '
                 'free-form object. (maybe annotate a Serializer class?)'
             )
-            schema = {
-                'type': 'object',
-                'additionalProperties': {},  # https://github.com/swagger-api/swagger-codegen/issues/1318
-                'description': 'Unspecified request body',
-            }
+            schema = build_object_type(
+                additionalProperties={},
+                description='Unspecified request body',
+            )
 
         request_body = {
             'content': {
