@@ -12,6 +12,7 @@ from django import __version__ as DJANGO_VERSION
 from django.urls.resolvers import _PATH_PARAMETER_COMPONENT_RE, get_resolver  # type: ignore
 from django.utils.module_loading import import_string
 from rest_framework import fields, serializers, versioning, exceptions
+from uritemplate import URITemplate
 
 from drf_spectacular.settings import spectacular_settings
 from drf_spectacular.types import (
@@ -143,6 +144,25 @@ def build_array_type(schema):
     }
 
 
+def build_object_type(
+        properties=None,
+        required=None,
+        description=None,
+        **kwargs
+):
+    schema = {'type': 'object'}
+    if description:
+        schema['description'] = description.strip()
+    if properties:
+        schema['properties'] = properties
+    if 'additionalParameters' in kwargs:
+        schema['additionalParameters'] = kwargs.pop('additionalParameters')
+    if required:
+        schema['required'] = sorted(required)
+    schema.update(kwargs)
+    return schema
+
+
 def build_parameter_type(
         name,
         schema,
@@ -317,7 +337,7 @@ class ComponentRegistry:
         self._components = {}
 
     def register(self, component: ResolvedComponent):
-        if self._components.get(component.key, None):
+        if component.key in self._components:
             warn(
                 f'trying to re-register a {component.type} component with name '
                 f'{self._components[component.key].name}. this might lead to '
@@ -408,7 +428,7 @@ class OpenApiGeneratorExtension(Generic[T], metaclass=ABCMeta):
         return None
 
 
-def postprocess_schema_enums(result, **kwargs):
+def postprocess_schema_enums(result, generator, **kwargs):
     """
     simple replacement of Enum/Choices that globally share the same name and have
     the same choices. Aids client generation to not generate a separate enum for
@@ -424,7 +444,6 @@ def postprocess_schema_enums(result, **kwargs):
             yield from iter_prop_containers(schema.get('oneOf', []))
             yield from iter_prop_containers(schema.get('allOf', []))
 
-    # schemas will be modified in-place and same result object is returned
     schemas = result.get('components', {}).get('schemas', {})
 
     hash_mapping = defaultdict(set)
@@ -452,11 +471,20 @@ def postprocess_schema_enums(result, **kwargs):
             enum_name = f'{inflection.camelize(prop_name)}Enum'
             enum_schema = {k: v for k, v in prop_schema.items() if k in ['type', 'enum']}
             prop_schema = {k: v for k, v in prop_schema.items() if k not in ['type', 'enum']}
-            prop_schema['$ref'] = f'#/components/schemas/{enum_name}'
 
-            schemas[enum_name] = enum_schema
+            component = ResolvedComponent(
+                name=enum_name,
+                type=ResolvedComponent.SCHEMA,
+                schema=enum_schema,
+                object=enum_name,
+            )
+            if component not in generator.registry:
+                generator.registry.register(component)
+            prop_schema.update(component.ref)
             props[prop_name] = safe_ref(prop_schema)
 
+    # sort again with additional components
+    result['components'] = generator.registry.build(spectacular_settings.APPEND_COMPONENTS)
     return result
 
 
@@ -510,7 +538,9 @@ def modify_for_versioning(patterns, method, path, view, requested_version):
     if issubclass(view.versioning_class, versioning.URLPathVersioning):
         version_param = view.versioning_class.version_param
         # substitute version variable to emulate request
-        path = uritemplate.expand(path, var_dict={version_param: requested_version})
+        path = uritemplate.partial(path, var_dict={version_param: requested_version})
+        if isinstance(path, URITemplate):
+            path = path.uri
         # emulate router behaviour by injecting substituted variable into view
         view.kwargs[version_param] = requested_version
     elif issubclass(view.versioning_class, versioning.NamespaceVersioning):
