@@ -1,10 +1,12 @@
 import yaml
 from rest_framework.exceptions import ErrorDetail
-from rest_framework.renderers import OpenAPIRenderer, JSONRenderer
+from rest_framework.renderers import JSONRenderer, BaseRenderer
 
 
-class OpenApiYamlRenderer(OpenAPIRenderer):
+class OpenApiYamlRenderer(BaseRenderer):
     media_type = 'application/vnd.oai.openapi'
+    charset = None
+    format = 'openapi'
 
     def render(self, data, media_type=None, renderer_context=None):
         # disable yaml advanced feature 'alias' for clean, portable, and readable output
@@ -16,6 +18,12 @@ class OpenApiYamlRenderer(OpenAPIRenderer):
             return dumper.represent_dict({'string': str(data), 'code': data.code})
         Dumper.add_representer(ErrorDetail, error_detail_representer)
 
+        def multiline_str_representer(dumper, data):
+            scalar = dumper.represent_str(data)
+            scalar.style = '|' if '\n' in data else None
+            return scalar
+        Dumper.add_representer(str, multiline_str_representer)
+
         return yaml.dump(
             data,
             default_flow_style=False,
